- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAsync(
K key) → FutureOr< void> -
fillAsync(
K key, V value) → void -
getAsync(
K key) → FutureOr< V> -
getOrAsync(
K key, V value) → FutureOr< V> -
getOrWriteAsync(
K key, V value) → FutureOr< V> -
hasAsync(
K key) → FutureOr< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAsync(
) → FutureOr< Map< K, V> > -
toString(
) → String -
A string representation of this object.
inherited
-
tryGetAsync(
K key) → FutureOr< V?> -
writeAllAsync(
Map< K, V> m) → FutureOr<void> -
writeAsync(
K key, V value) → FutureOr< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited